User class

A user account.

Properties

displayName → String?
The users display name.
no setter
email → String?
The users email address.
no setter
emailVerified → bool
Returns whether the users email address has been verified.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAnonymous → bool
Returns whether the user is a anonymous.
no setter
metadata → UserMetadata
Returns additional metadata about the user, such as their creation time.
no setter
phoneNumber → String?
Returns the users phone number.
no setter
photoURL → String?
Returns a photo URL for the user.
no setter
providerData → List<UserInfo>
Returns a list of user information for each linked provider.
no setter
refreshToken → String?
Returns a JWT refresh token for the user.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenantId → String?
The current user's tenant ID.
no setter
uid → String
The user's unique ID.
no setter

Methods

getIdToken([bool forceRefresh = false]) → Future<String>
Returns a JSON Web Token (JWT) used to identify the user to a Firebase service.
getIdTokenResult([bool forceRefresh = false]) → Future<IdTokenResult>
Returns a IdTokenResult containing the users JSON Web Token (JWT) and other metadata.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → Future<void>
Refreshes the current user, if signed in.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited