UserCredential class

A UserCredential is returned from authentication requests such as createUserWithEmailAndPassword.

Properties

additionalUserInfo → AdditionalUserInfo?
Returns additional information about the user, such as whether they are a newly created one.
no setter
credential → AuthCredential?
The users AuthCredential.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → User?
Returns a User containing additional information and user specific methods.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited