AuthProvider class abstract

A base class which all providers must extend.

Implementers

Constructors

AuthProvider(String providerId)
Constructs a new instance with a given provider identifier.

Properties

hashCode → int
The hash code for this object.
no setterinherited
providerId → String
The provider ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited