FirebaseAuthException class

Generic exception related to Firebase Authentication. Check the error code and message for more details.

Inheritance
Implemented types

Constructors

FirebaseAuthException({String? message, required String code, String? email, AuthCredential? credential, String? phoneNumber, String? tenantId})

Properties

code → String
The optional code to accommodate the message.
finalinherited
credential → AuthCredential?
The AuthCredential that can be used to resolve the error.
final
email → String?
The email of the user's account used for sign-in/linking.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The long form message of the exception.
finalinherited
phoneNumber → String?
The phone number of the user's account used for sign-in/linking.
final
plugin → String
The plugin the exception is for.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace which provides information to the user about the call sequence that triggered an exception
finalinherited
tenantId → String?
The tenant ID being used for sign-in/linking.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited