OAuthProvider class

A generic provider instance.

This class is extended by other OAuth based providers, or can be used standalone for integration with other 3rd party providers.

Inheritance

Constructors

OAuthProvider(String providerId)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameters → Map
Returns the parameters for this provider instance.
no setter
providerId → String
The provider ID.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>
Returns the currently assigned scopes to this provider instance.
no setter

Methods

addScope(String scope) → OAuthProvider
Adds OAuth scope.
credential({String? accessToken, String? secret, String? idToken, String? rawNonce, String? signInMethod}) → OAuthCredential
Create a new OAuthCredential from a provided accessToken;
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomParameters(Map customOAuthParameters) → OAuthProvider
Sets the OAuth custom parameters to pass in a OAuth request for popup and redirect sign-in operations.
setScopes(List<String> scopes) → OAuthProvider
Returns the parameters for this provider instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited