UserInfo class

User profile information, visible only to the Firebase project's apps.

Constructors

UserInfo(Map<String, String?> _data)

Properties

displayName → String?
The users display name.
no setter
email → String?
The users email address.
no setter
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber → String?
Returns the users phone number.
no setter
photoURL → String?
Returns a photo URL for the user.
no setter
providerId → String
The federated provider ID.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String?
The user's unique ID.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited