FirebaseApp class

Represents a single Firebase app instance.

You can get an instance by calling Firebase.app().

Properties

hashCode → int
The hash code for this object.
no setteroverride
isAutomaticDataCollectionEnabled → bool
Returns whether automatic data collection is enabled or disabled for this app.
no setter
name → String
The name of this FirebaseApp.
no setter
options → FirebaseOptions
The FirebaseOptions this app was created with.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
Deletes this app and frees up system resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAutomaticDataCollectionEnabled(bool enabled) → Future<void>
Sets whether automatic data collection is enabled or disabled for this app.
setAutomaticResourceManagementEnabled(bool enabled) → Future<void>
Sets whether automatic resource management is enabled or disabled for this app.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override