FirebaseAppPlatform class

A class storing the name and options of a Firebase app.

This is created as a result of calling FirebasePlatform.initializeApp.

Inheritance
  • Object
  • PlatformInterface
  • FirebaseAppPlatform
Implementers

Constructors

FirebaseAppPlatform(String name, FirebaseOptions options)

Properties

hashCode → int
The hash code for this object.
no setteroverride
isAutomaticDataCollectionEnabled → bool
Returns true if automatic data collection is enabled for this app.
no setter
name → String
The name of this Firebase app.
final
options → FirebaseOptions
Returns the FirebaseOptions that this app was configured with.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
Deletes the current FirebaseApp.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAutomaticDataCollectionEnabled(bool enabled) → Future<void>
Sets whether automatic data collection is enabled or disabled for this app.
setAutomaticResourceManagementEnabled(bool enabled) → Future<void>
Sets whether automatic resource management is enabled or disabled for this app.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

verify(FirebaseAppPlatform instance) → void
Ensures that the platform instance was constructed with a non-const token that matches the provided token and throws AssertionError if not.
override