FirebaseOptions class

The options used to configure a Firebase app.

await Firebase.initializeApp(
  name: 'SecondaryApp',
  options: const FirebaseOptions(
    apiKey: '...',
    appId: '...',
    messagingSenderId: '...',
    projectId: '...',
  )
);
Annotations

Constructors

FirebaseOptions({required String apiKey, required String appId, required String messagingSenderId, required String projectId, String? authDomain, String? databaseURL, String? storageBucket, String? measurementId, String? trackingId, String? deepLinkURLScheme, String? androidClientId, String? iosClientId, String? iosBundleId, String? appGroupId})
The options used to configure a Firebase app.
const
FirebaseOptions.fromPigeon(PigeonFirebaseOptions options)
Named constructor to create FirebaseOptions from a the response of Pigeon channel.

Properties

androidClientId → String?
The Android client ID from the Firebase Console, for example "12345.apps.googleusercontent.com."
final
apiKey → String
An API key used for authenticating requests from your app to Google servers.
final
appGroupId → String?
The iOS App Group identifier to share data between the application and the application extensions.
final
appId → String
The Google App ID that is used to uniquely identify an instance of an app.
final
asMap → Map<String, String?>
The current instance as a Map.
no setter
authDomain → String?
The auth domain used to handle redirects from OAuth provides on web platforms, for example "my-awesome-app.firebaseapp.com".
final
databaseURL → String?
The database root URL, for example "https://my-awesome-app.firebaseio.com."
final
deepLinkURLScheme → String?
The URL scheme used by iOS secondary apps for Dynamic Links.
final
hashCode → int
The hash code for this object.
no setteroverride
iosBundleId → String?
The iOS bundle ID for the application. Defaults to [[NSBundle mainBundle] bundleID] when not set manually or in a plist.
final
iosClientId → String?
The iOS client ID from the Firebase Console, for example "12345.apps.googleusercontent.com."
final
measurementId → String?
The project measurement ID value used on web platforms with analytics.
final
messagingSenderId → String
The unique sender ID value used in messaging to identify your app.
final
projectId → String
The Project ID from the Firebase console, for example "my-awesome-app".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageBucket → String?
The Google Cloud Storage bucket name, for example "my-awesome-app.appspot.com".
final
trackingId → String?
The tracking ID for Google Analytics, for example "UA-12345678-1", used to configure Google Analytics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override