MethodChannelFirebase class

The FirebasePlatform implementation that delegates to a MethodChannel.

Inheritance

Constructors

MethodChannelFirebase()

Properties

apps → List<FirebaseAppPlatform>
Returns the created FirebaseAppPlatform instances.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

app([String name = defaultFirebaseAppName]) → FirebaseAppPlatform
Returns a FirebaseAppPlatform by name.
override
initializeApp({String? name, FirebaseOptions? options}) → Future<FirebaseAppPlatform>
Initializes a Firebase app instance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

api ↔ FirebaseCoreHostApi
Keeps track of whether users have initialized core.
getter/setter pair
appInstances ↔ Map<String, MethodChannelFirebaseApp>
Tracks local MethodChannelFirebaseApp instances.
getter/setter pair
isCoreInitialized ↔ bool
Keeps track of whether users have initialized core.
getter/setter pair