MethodChannelFirebaseApp class

The entry point for accessing a Firebase app instance.

To get an instance, call the app method on the FirebaseCore instance, for example:

Firebase.app('SecondaryApp`);
Inheritance

Constructors

MethodChannelFirebaseApp(String name, FirebaseOptions options, {dynamic isAutomaticDataCollectionEnabled})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAutomaticDataCollectionEnabled → bool
Returns whether automatic data collection enabled or disabled.
no setteroverride
name → String
The name of this Firebase app.
finalinherited
options → FirebaseOptions
Returns the FirebaseOptions that this app was configured with.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
Deletes the current Firebase app instance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAutomaticDataCollectionEnabled(bool enabled) → Future<void>
Sets whether automatic data collection is enabled or disabled.
override
setAutomaticResourceManagementEnabled(bool enabled) → Future<void>
Sets whether automatic resource management is enabled or disabled.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited