FirebaseStorage class

The entrypoint for FirebaseStorage.

Inheritance

Properties

app ↔ FirebaseApp
The FirebaseApp for this current FirebaseStorage instance.
getter/setter pair
bucket ↔ String
The storage bucket of this instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
maxDownloadRetryTime → Duration
The maximum time to retry downloads in milliseconds.
no setter
maxOperationRetryTime → Duration
The maximum time to retry operations other than uploads or downloads in milliseconds.
no setter
maxUploadRetryTime → Duration
The maximum time to retry uploads in milliseconds.
no setter
pluginConstants → Map
Returns any plugin constants this plugin app instance has initialized.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ref([String? path]) → Reference
Returns a new Reference.
refFromURL(String url) → Reference
Returns a new Reference from a given URL.
setMaxDownloadRetryTime(Duration time) → void
Sets the new maximum download retry time.
setMaxOperationRetryTime(Duration time) → void
Sets the new maximum operation retry time.
setMaxUploadRetryTime(Duration time) → void
Sets the new maximum upload retry time.
toString() → String
A string representation of this object.
override
useEmulator({required String host, required int port}) → Future<void>
Changes this instance to point to a Storage emulator running locally.
useStorageEmulator(String host, int port) → Future<void>
Changes this instance to point to a Storage emulator running locally.

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

instance → FirebaseStorage
Returns an instance using the default FirebaseApp.
no setter

Static Methods

instanceFor({FirebaseApp? app, String? bucket}) → FirebaseStorage
Returns an instance using a specified FirebaseApp and/or custom storage bucket.