ListResult class

Class returned as a result of calling a list method (list or listAll) on a Reference.

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<Reference>
Objects in this directory.
no setter
nextPageToken → String?
If set, there might be more results for this list.
no setter
prefixes → List<Reference>
References to prefixes (sub-folders). You can call list() on them to get its contents.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → FirebaseStorage
The FirebaseStorage instance for this result.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited