Task class abstract

A class representing an on-going storage task that additionally delegates to a Future.

Implemented types
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot → TaskSnapshot
The latest TaskSnapshot for this task.
no setter
snapshotEvents → Stream<TaskSnapshot>
Returns a Stream of TaskSnapshot events.
no setter
storage → FirebaseStorage
The FirebaseStorage instance associated with this task.
final

Methods

asStream() → Stream<TaskSnapshot>
Creates a Stream containing the result of this future.
override
cancel() → Future<bool>
Cancels the current task.
catchError(Function onError, {bool test(Object error)?}) → Future<TaskSnapshot>
Handles errors emitted by this Future.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<bool>
Pauses the current task.
override
resume() → Future<bool>
Resumes the current task.
then<S>(FutureOr<S> onValue(TaskSnapshot), {Function? onError}) → Future<S>
Register callbacks to be called when this future completes.
override
timeout(Duration timeLimit, {FutureOr<TaskSnapshot> onTimeout()?}) → Future<TaskSnapshot>
Stop waiting for this future after timeLimit has passed.
override
toString() → String
A string representation of this object.
inherited
whenComplete(FutureOr action()) → Future<TaskSnapshot>
Registers a function to be called when this future completes.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited