TaskSnapshot class

A TaskSnapshot is returned as the result or on-going process of a Task.

Properties

bytesTransferred → int
The current transferred bytes of this task.
no setter
hashCode → int
The hash code for this object.
no setteroverride
metadata → FullMetadata?
The FullMetadata associated with this task.
no setter
ref → Reference
The Reference for this snapshot.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TaskState
The current task snapshot state.
no setter
storage → FirebaseStorage
The FirebaseStorage instance used to create the task.
final
totalBytes → int
The total bytes of the task.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override