UploadTask class

A class which indicates an on-going upload task.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot → TaskSnapshot
The latest TaskSnapshot for this task.
no setterinherited
snapshotEvents → Stream<TaskSnapshot>
Returns a Stream of TaskSnapshot events.
no setterinherited
storage → FirebaseStorage
The FirebaseStorage instance associated with this task.
finalinherited

Methods

asStream() → Stream<TaskSnapshot>
Creates a Stream containing the result of this future.
inherited
cancel() → Future<bool>
Cancels the current task.
inherited
catchError(Function onError, {bool test(Object error)?}) → Future<TaskSnapshot>
Handles errors emitted by this Future.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<bool>
Pauses the current task.
inherited
resume() → Future<bool>
Resumes the current task.
inherited
then<S>(FutureOr<S> onValue(TaskSnapshot), {Function? onError}) → Future<S>
Register callbacks to be called when this future completes.
inherited
timeout(Duration timeLimit, {FutureOr<TaskSnapshot> onTimeout()?}) → Future<TaskSnapshot>
Stop waiting for this future after timeLimit has passed.
inherited
toString() → String
A string representation of this object.
inherited
whenComplete(FutureOr action()) → Future<TaskSnapshot>
Registers a function to be called when this future completes.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited