FullMetadata class

The result of calling getMetadata on a storage object reference.

Constructors

FullMetadata(Map<String, dynamic> _metadata)

Properties

bucket → String?
The bucket this object is contained in.
no setter
cacheControl → String?
Served as the 'Cache-Control' header on object download.
no setter
contentDisposition → String?
Served as the 'Content-Disposition' HTTP header on object download.
no setter
contentEncoding → String?
Served as the 'Content-Encoding' header on object download.
no setter
contentLanguage → String?
Served as the 'Content-Language' header on object download.
no setter
contentType → String?
Served as the 'Content-Type' header on object download.
no setter
customMetadata → Map<String, String>?
Custom metadata set on this storage object.
no setter
fullPath → String
The full path of this object.
no setter
generation → String?
The object's generation.
no setter
hashCode → int
The hash code for this object.
no setterinherited
md5Hash → String?
A Base64-encoded MD5 hash of the object being uploaded.
no setter
metadataGeneration → String?
The object's metadata generation.
no setter
metageneration → String?
The object's metageneration.
no setter
name → String
The short name of this object, which is the last component of the full path.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
The size of this object, in bytes.
no setter
timeCreated → DateTime?
A DateTime representing when this object was created.
no setter
updated → DateTime?
A DateTime representing when this object was updated.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited